<?php
/*
 Plugin Name: Tickera - Print tickets
 Plugin URI: http://tickera.com/
 Description: Adds options to allow ticket printing on both front and back end
 Author: Tickera.com
 Author URI: http://tickera.com/
 Version: 1.0
 TextDomain: tc_print
 Domain Path: /languages/
 Copyright 2023 Tickera (http://tickera.com/)
*/

if ( !defined( 'ABSPATH' ) )
    exit; // Exit if accessed directly


add_action( 'admin_enqueue_scripts', 'tc_backend_print_load_assets' );
add_action( 'wp_enqueue_scripts', 'tc_frontend_print_load_assets' );

 /**
         * Plugin localization function
         */
        function localization() {

            /*
             * Load up the localization file if we're using WordPress in a different language
             * Place it in this plugin's "languages" folder and name it "tccsv-[value in wp-config].mo"
             */
            if ( 'mu-plugins' == $this->location ) {
                load_muplugin_textdomain( 'tc_print', 'languages/' );

            } elseif ( 'subfolder-plugins' == $this->location ) {
                load_plugin_textdomain( 'tc_print', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

            } elseif ( 'plugins' == $this->location ) {
                load_plugin_textdomain( 'tc_print', false, 'languages/' );
            }

            $temp_locales = explode( '_', get_locale() );
            $this->language = ( $temp_locales[ 0 ] ) ? $temp_locales[ 0 ] : 'en';
        }


function tc_backend_print_load_assets() {
    wp_enqueue_script( 'print-min', plugins_url( '/js/print.min.js' , __FILE__ ));
    wp_enqueue_style( 'style', plugins_url( '/css/style.css' , __FILE__ ) );
}

function tc_frontend_print_load_assets() {
    wp_enqueue_script( 'print-min', plugins_url( '/js/print.min.js' , __FILE__ ));
    wp_enqueue_style( 'style', plugins_url( '/css/style.css' , __FILE__ ) );
}

//Add options to settings
add_filter('tc_settings_general_sections','tc_print_settings', 11, 2 );

function tc_print_settings( $sections ) {

    $sections[] = [
        'name' => 'print_settings',
        'title' => __( 'Print Options', 'tc_print' ),
        'description' => '',
    ];

    return $sections;
}




add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_print_on_back');
add_filter( 'tc_general_settings_miscellaneous_fields', 'tc_general_settings_miscellaneous_fields_print_on_front');


function tc_general_settings_miscellaneous_fields_print_on_back( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_print_option_back',
        'field_title'	 => __( 'Enable printing in the back end?', 'tc_print' ),
        'field_type'     => 'function',
        'function'       => 'tc_yes_no',
        'default_value'	 => '',
        'tooltip'		 => __('If set to Yes, you will be able to print tickets directly from the Attendees & Tickets area', 'tc_print'),
        'section'		 => 'print_settings',
    );
    return $fields;
}

$tc_get_option			 = get_option( 'tc_general_setting', false );
$tc_print_back_enabled	 = isset( $tc_get_option[ 'tc_print_option_back' ] ) ? $tc_get_option[ 'tc_print_option_back' ] : '';

if ($tc_print_back_enabled === "yes") {
    require_once(dirname(__FILE__) . '/includes/backend.php');
}


function tc_general_settings_miscellaneous_fields_print_on_front( $fields ) {
    $fields [] = array(
        'field_name'	 => 'tc_print_option_front',
        'field_title'	 => __( 'Enable printing on the front end?', 'tc_print' ),
        'field_type'     => 'function',
        'function'       => 'tc_yes_no',
        'default_value'	 => '',
        'tooltip'		 => __('If set to Yes, customers will be able to print tickets without needing to download them first', 'tc_print'),
        'section'		 => 'print_settings',
    );
    return $fields;
}

$tc_get_option			 = get_option( 'tc_general_setting', false );
$tc_print_front_enabled	 = isset( $tc_get_option[ 'tc_print_option_front' ] ) ? $tc_get_option[ 'tc_print_option_front' ] : '';

if ($tc_print_front_enabled === "yes") {
    require_once(dirname(__FILE__) . '/includes/frontend.php');
}







